@@ -8,6 +8,7 @@ from sql.conditionals import Coalesce
 
 from trytond.pool import PoolMeta, Pool
 from trytond.model import fields
+from trytond.pyson import Eval
 from trytond.transaction import Transaction
 from trytond.tools import grouped_slice, reduce_ids
 
@@ -19,7 +20,9 @@ class Party:
     __metaclass__ = PoolMeta
     __name__ = 'party.party'
 
-    deposit = fields.Function(fields.Numeric('Deposit'),
+    deposit = fields.Function(fields.Numeric('Deposit',
+            digits=(16, Eval('currency_digits', 2)),
+            depends=['currency_digits']),
         'get_deposit', searcher='search_deposit')
 
     @classmethod
@@ -47,7 +50,8 @@ class Party:
             cursor.execute(*line.join(account,
                     condition=account.id == line.account
                     ).select(line.party,
-                    Sum(Coalesce(line.debit, 0) - Coalesce(line.credit, 0)),
+                    # Use credit - debit to positive deposit amount
+                    Sum(Coalesce(line.credit, 0) - Coalesce(line.debit, 0)),
                     where=account.active
                     & (account.kind == 'deposit')
                     & party_clause
